@@ -267,12 +267,12 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unkno
     print('File Parsing')
     print("-" * 10)
     refl = refl_data.Profile(files_to_reduce, the_boss.reduction.parser,
-                             the_boss.experiment.measurement.q_axis_name,
-                             the_boss.experiment.measurement.theta_axis_name,
+                             the_boss.data_source.experiment.measurement.q_axis_name,
+                             the_boss.data_source.experiment.measurement.theta_axis_name,
                              None, 0,
-                             the_boss.experiment.measurement.pixel_max,
-                             the_boss.experiment.measurement.hot_pixel_max,
-                             the_boss.experiment.measurement.transpose)
+                             the_boss.data_source.experiment.measurement.pixel_max,
+                             the_boss.data_source.experiment.measurement.hot_pixel_max,
+                             the_boss.data_source.experiment.measurement.transpose)
     print("-" * 10)
     print('Cropping')
     print("-" * 10)
@@ -288,7 +288,7 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', title='Unkno
     print("-" * 10)
     print('Estimating Resolution Function')
     print("-" * 10)
-    refl.resolution_function(the_boss.experiment.measuremnt.qz_dimension,
+    refl.resolution_function(the_boss.data_source.experiment.measuremnt.qz_dimension,
                              progress=True)
     the_boss.reduction.data_state.resolution = 'estimated'
 
